@@ -37,14 +37,27 @@ public:
     QList<QAction*> actionsList;
     KService::Ptr service;
     MenuItem *rootItem = nullptr;
+    MenuItem *homeItem = nullptr;
+    QString startupModule;
+    QStringList startupModuleArgs;
     KConfigGroup config;
     bool showToolTips = true;
+    BaseMode::ApplicationMode applicationMode = BaseMode::SystemSettings;
 };
 
-BaseMode::BaseMode( QObject* parent )
+BaseMode::BaseMode( QObject* parent, const QVariantList &args )
     : QObject( parent )
     , d( new Private() )
 {
+    if (args.count() >= 1 && args.first().canConvert<ApplicationMode>()) {
+        d->applicationMode = args.first().value<ApplicationMode>();
+    }
+    if (args.count() >= 2 && args[1].canConvert<QString>()) {
+        d->startupModule = args[1].toString();
+    }
+    if (args.count() >= 3 && args[2].canConvert<QStringList>()) {
+        d->startupModuleArgs = args[2].toStringList();
+    }
 }
 
 BaseMode::~BaseMode()
@@ -55,6 +68,7 @@ BaseMode::~BaseMode()
 void BaseMode::init( const KService::Ptr &modeService )
 {
     d->rootItem = BaseData::instance()->menuItem();
+    d->homeItem = BaseData::instance()->homeItem();
     d->service = modeService;
     d->config = BaseData::instance()->configGroup( modeService->library() );
     initEvent();
@@ -75,6 +89,11 @@ KAboutData * BaseMode::aboutData()
     return nullptr;
 }
 
+BaseMode::ApplicationMode BaseMode::applicationMode() const
+{
+    return d->applicationMode;
+}
+
 ModuleView * BaseMode::moduleView() const
 {
     return nullptr;
@@ -100,6 +119,26 @@ bool BaseMode::showToolTips() const
     return d->showToolTips;
 }
 
+void BaseMode::setStartupModule(const QString &startupModule)
+{
+    d->startupModule = startupModule;
+}
+
+QString BaseMode::startupModule() const
+{
+    return d->startupModule;
+}
+
+void BaseMode::setStartupModuleArgs(const QStringList &startupModuleArgs)
+{
+    d->startupModuleArgs = startupModuleArgs;
+}
+
+QStringList BaseMode::startupModuleArgs() const
+{
+    return d->startupModuleArgs;
+}
+
 void BaseMode::searchChanged( const QString& text )
 {
     Q_UNUSED( text );
@@ -135,6 +174,11 @@ MenuItem * BaseMode::rootItem() const
     return d->rootItem;
 }
 
+MenuItem * BaseMode::homeItem() const
+{
+    return d->homeItem;
+}
+
 KConfigGroup& BaseMode::config() const
 {
     return d->config;
