@@ -51,18 +51,27 @@ class SYSTEMSETTINGSVIEW_EXPORT BaseMode : public QObject
     Q_OBJECT
 
     /**
-     * System Settings main application is allowed privilaged access to handle tooltips
+     * System Settings main application is allowed priviledged access to handle tooltips
      */
     friend class SettingsBase;
 
 public:
+    // Main mode of the app.
+    // At the moment SystemSettings and InfoCenter are supported:
+    // Changes mainly the set of module listed on the left menu
+    enum ApplicationMode {
+        SystemSettings = 0,
+        InfoCenter
+    };
+    Q_ENUM(ApplicationMode);
+
     /**
      * Constructs a BaseMode for use in System Settings.\n
      * Plugin developers should perform all initialisation in initEvent() not here.
      *
      * @param parent The parent of this BaseMode.
      */
-    explicit BaseMode( QObject * parent );
+    explicit BaseMode( QObject * parent, const QVariantList &args );
     /**
      * Normal destructor. Plugin developers only need destroy what they created
      * not what is provided by BaseMode itself.
@@ -86,7 +95,7 @@ public:
      *
      * @param modeService Plugins service object, used for providing extra information to System Settings.
      */
-    void init( const KService::Ptr modeService );
+    void init( const KService::Ptr &modeService );
 
     /**
      * Prepares the BaseMode for use.\n
@@ -113,6 +122,11 @@ public:
      */
     virtual KAboutData * aboutData();
 
+    /**
+     * @returns the application mode of this systemsettings process: SystemSettings or InfoCenter
+     */
+    ApplicationMode applicationMode() const;
+
     /**
      * The state of the plugin ( position of the splitter for instance ) should be saved
      * to the configuration object when this is called.
@@ -130,7 +144,7 @@ public:
     /**
      * Used to give focus to the plugin. Plugin should call setFocus() on the appropriate widget
      *
-     * @note Failure to reimplement will cause keyboard accessibiltity and widget focusing problems
+     * @note Failure to reimplement will cause keyboard accessibility and widget focusing problems
      */
     virtual void giveFocus();
 
@@ -160,7 +174,7 @@ public:
     const KService::Ptr& service() const;
 
     /**
-     * tells the config view wether to make use of tooltips or not
+     * tells the config view whether to make use of tooltips or not
      */
     void setShowToolTips( bool show);
 
@@ -169,6 +183,14 @@ public:
      */
     bool showToolTips() const;
 
+    void setStartupModule(const QString &startupModule);
+    QString startupModule() const;
+
+    void setStartupModuleArgs(const QStringList &startupModuleArgs);
+    QStringList startupModuleArgs() const;
+
+    virtual void reloadStartupModule() = 0;
+
 public Q_SLOTS:
     /**
      * Called when the text in the search box changes allowing the display to be filtered.
@@ -191,7 +213,7 @@ public Q_SLOTS:
     virtual void loadConfiguration();
 
     /**
-     * Should be implmented to ensure that views settings are saved when the user confirms their changes
+     * Should be implemented to ensure that views settings are saved when the user confirms their changes
      * Views should also apply the configuration at the same time
      */
     virtual void saveConfiguration();
@@ -231,6 +253,14 @@ protected:
      */
     MenuItem * rootItem() const;
 
+    /**
+     * Returns (if present) an item that corresponds to a KCM which should be used as startup page.
+     *
+     * @warning This is shared between all views, and should not be deleted manually.
+     * @returns The item to load as startup page. It may be nullptr
+     */
+    MenuItem * homeItem() const;
+
     /**
      * Provides access to the configuration for the plugin.
      *
