@@ -78,13 +78,15 @@ class SidebarMode : public BaseMode
     Q_PROPERTY(bool introPageVisible READ introPageVisible WRITE setIntroPageVisible NOTIFY introPageVisibleChanged)
 
 public:
-    SidebarMode(QObject * parent, const QVariantList& );
+    SidebarMode(QObject * parent, const QVariantList &args );
     ~SidebarMode() override;
     QWidget * mainWidget() override;
     void initEvent() override;
     void giveFocus() override;
     KAboutData * aboutData() override;
     ModuleView * moduleView() const override;
+    void reloadStartupModule() override;
+
     QAbstractItemModel *categoryModel() const;
     QAbstractItemModel *searchModel() const;
     QAbstractItemModel *subCategoryModel() const;
@@ -110,7 +112,7 @@ public:
     Q_INVOKABLE void hideMostUsedToolTip();
     Q_INVOKABLE void showActionMenu(const QPoint &position);
 
-    Q_INVOKABLE void loadModule(const QModelIndex& activeModule);
+    Q_INVOKABLE void loadModule(const QModelIndex& activeModule, const QStringList &args = QStringList());
 
 protected:
     QList<QAbstractItemView*> views() const override;
